@@ -16,7 +16,7 @@ except Exception, e:
     import sys
     sys.exit(1)
 finally:
-    if globals.has_key('REQUIRED_VARS'):
+    if 'REQUIRED_VARS' in globals().keys():
         configdir.failOnMissing(globals(), REQUIRED_VARS)
 
 """
